import { GLOBAL_PARAMS } from "../helper/serializableitem";
import { Graph } from "./graph";
import { GraphElement } from "./graphelement";
import * as Common from "../../../../common/graph";

const NODE_TYPE_PARAMS = ["name", "color", ...GLOBAL_PARAMS];

export class NodeType extends GraphElement implements Common.GraphObjectType {
    public name: string;
    public color: string;

    serialize(): any {
        return this.serializeProperties(NODE_TYPE_PARAMS);
    }

    public delete(): boolean {
        return this.graph.deleteNodeType(this);
    }

    public add(graph: Graph = this.graph): boolean {
        this.graph = graph;
        if (this.graph == undefined) {
            return false;
        }

        return this.graph.addNodeType(this);
    }

    public getCleanInstance(): any {
        return this.serialize();
    }

    public static parse(raw: any): NodeType {
        const type: NodeType = new NodeType();

        if (typeof raw === "string" || raw instanceof String) {
            type.name = raw as string;
            type.color = "#ff0000";
        } else {
            type.name = raw.name;
            type.color = raw.color;
        }

        return type;
    }

    public toString(): string {
        return this.name;
    }

    public equals(other: GraphElement): boolean {
        if (other.link || other.node) {
            return false;
        }

        const type = other as NodeType;

        return type.id === this.id;
    }
}
